/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2005  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef CFUTILS_H_
#define CFUTILS_H_

#include <CoreFoundation/CoreFoundation.h>
#include "RefPtr.h"
#include <string>

class CFUtils
{
public:
	static ArrayRef createCFTypeArray(CFTypeRef first, ...);
	
	static StringRef composePath(CFStringRef first, ...);
	
	static StringRef extractLastPathComponent(StringRef const& path);
	
	static StringRef removeStringPrefix(
		StringRef const& string, CFStringRef prefix);
	
	static std::string stringToUtf8(CFStringRef str);
};

#endif
